@@ -1,4 +1,5 @@
 import StringIO
+import datetime
 
 from django.db.models import Max
 from django.http import HttpResponse
@@ -31,6 +32,8 @@ CUSTOM_LEGENDS = 'custom_legends'
 MAP_LOCATION = 'map_location'
 MAP_BASE_LAYER = 'map_base_layer'  # The selected base layer
 CRUMBS_HOMEPAGE = {'name': 'home', 'title': 'hoofdpagina', 'url': '/'}
+POPUP_VIDEO_LAST_SEEN = 'popup_video_last_seen_time'
+TIME_BETWEEN_VIDEO_POPUP = datetime.timedelta(days=1)
 
 logger = logging.getLogger(__name__)
 
@@ -38,6 +41,7 @@ logger = logging.getLogger(__name__)
 def homepage(request,
              template='lizard_map/app_screen.html',
              crumbs_prepend=None,
+             popup_video_url=None,
              application_screen_slug=None):
     """Default apps screen, make your own template.
 
@@ -53,9 +57,25 @@ def homepage(request,
     if application_screen_slug is None:
         application_screen_slug = request.GET.get('screen', None)
 
+    # Determine if we want to show the video. Only show it once every day or
+    # so.
+    if popup_video_url is not None:
+        now = datetime.datetime.now()
+        if not POPUP_VIDEO_LAST_SEEN in request.session:
+            # Record the time and show the popup.
+            request.session[POPUP_VIDEO_LAST_SEEN] = now
+        elif ((now - request.session[POPUP_VIDEO_LAST_SEEN]) <
+            TIME_BETWEEN_VIDEO_POPUP):
+            # We've seen it recently enough, don't show it now.
+            popup_video_url = None
+        else:
+            # Record the new time and show the popup.
+            request.session[POPUP_VIDEO_LAST_SEEN] = now
+
     return render_to_response(
         template,
         {'crumbs': crumbs,
+         'popup_video_url': popup_video_url,
          'application_screen_slug': application_screen_slug},
         context_instance=RequestContext(request))
 
@@ -761,14 +781,19 @@ def wms(request, workspace_id):
     workspace_items = workspace.workspace_items.filter(visible=True).reverse()
     for workspace_item in workspace_items:
         logger.debug("Drawing layer for %s..." % workspace_item)
-        layers, styles = workspace_item.adapter.layer(layer_ids=layers,
-                                                      request=request)
-        layers.reverse()  # first item should be drawn on top (=last)
-        for layer in layers:
-            mapnik_map.layers.append(layer)
-        for name in styles:
-            mapnik_map.append_style(name, styles[name])
-        # mapnik_map.zoom_to_box(layer.envelope())
+        try:
+            layers, styles = workspace_item.adapter.layer(
+                layer_ids=layers,
+                request=request)
+            layers.reverse()  # first item should be drawn on top (=last)
+            for layer in layers:
+                mapnik_map.layers.append(layer)
+            for name in styles:
+                mapnik_map.append_style(name, styles[name])
+        except:
+            # This part may NEVER crash. Layers from workspace items
+            # should prevent crashing themselves, but you never know.
+            logger.exception("Error in drawing layer for %s" % workspace_item)
 
     #Zoom and create image
     logger.debug("Zooming to box...")
